@@ -29,14 +29,14 @@ add_cp <- function(pbp) {
       ) %>%
       dplyr::select(-"valid_pass")
 
-    usethis::ui_done("added cp and cpoe")
+    user_message("added cp and cpoe", "done")
   } else {
     pbp <- pbp %>%
       dplyr::mutate(
         cp = NA_real_,
         cpoe = NA_real_
       )
-    usethis::ui_info("No non-NA values for cp calculation detected. cp and cpoe set to NA")
+    user_message("No non-NA values for cp calculation detected. cp and cpoe set to NA", "info")
   }
 
   return(pbp)
